==> elevarm_ui-0.3.1.tar.gz: lib/src/components/charts/bar_charts/elevarm_stacked_vertical_bar_chart_card.dart <==
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

/// [ElevarmStackedVerticalBarChartCard]'s data series class.
class ElevarmStackedVerticalBarChartDataSeries {
  /// The series' data points.
  final List<ElevarmStackedVerticalBarChartData> dataPoints;

  /// The series' color.
  final Color color;

  /// The series' label.
  final String label;

  ElevarmStackedVerticalBarChartDataSeries({
    required this.label,
    required this.dataPoints,
    required this.color,
  });
}

/// [ElevarmStackedVerticalBarChartCard]'s data point class.
class ElevarmStackedVerticalBarChartData {
  /// The data point's label.
  final String label;

  /// The data point's value.
  final int value;

  ElevarmStackedVerticalBarChartData({
    required this.label,
    required this.value,
  });
}

/// Elevarm UI's stacked vertical bar chart inside a card.
class ElevarmStackedVerticalBarChartCard extends StatelessWidget {
  /// Chart's title.
  final String title;

  /// Chart's subtitle if any.
  final String? subtitle;

  /// Chart's list of data.
  final List<ElevarmStackedVerticalBarChartDataSeries> dataSource;

  /// Chart's tooltip title. If null [title] will be used.
  final String? tooltipTitle;

  const ElevarmStackedVerticalBarChartCard({
    super.key,
    required this.title,
    this.subtitle,
    required this.dataSource,
    this.tooltipTitle,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.zero,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12.0),
        boxShadow: ElevarmBoxShadow.sm,
        color: ElevarmColors.white,
      ),
      child: Padding(
        padding: const EdgeInsets.all(24.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text(
              title,
              style: ElevarmFontFamilies.inter(
                color: ElevarmColors.neutral,
                fontSize: ElevarmFontSizes.lg,
                fontWeight: ElevarmFontWeights.semibold,
              ),
            ),
            subtitle != null
                ? Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      const SizedBox(height: 2.0),
                      Text(
                        subtitle!,
                        style: ElevarmFontFamilies.inter(
                          color: const Color(
                            0xFF7A838F,
                          ), // FIXME: Not using ElevarmColors
                          fontSize: ElevarmFontSizes.sm,
                          fontWeight: ElevarmFontWeights.regular,
                        ),
                      ),
                    ],
                  )
                : Container(),
            const SizedBox(height: 8.0),
            SizedBox(
              height: 280,
              child: SfCartesianChart(
                margin: EdgeInsets.zero,
                primaryXAxis: CategoryAxis(
                  majorGridLines: const MajorGridLines(width: 0),
                  majorTickLines: const MajorTickLines(
                    color: Colors.transparent,
                  ),
                  axisLine: const AxisLine(
                    color: Colors.transparent,
                  ),
                  labelStyle: ElevarmFontFamilies.inter(
                    color: ElevarmColors.grey600,
                    fontSize: ElevarmFontSizes.xs,
                    fontWeight: ElevarmFontWeights.regular,
                  ),
                ),
                plotAreaBorderColor: Colors.transparent,
                primaryYAxis: CategoryAxis(
                  maximumLabelWidth: 0.0,
                  axisLine: const AxisLine(
                    color: Colors.transparent,
                  ),
                  majorTickLines: const MajorTickLines(
                    color: Colors.transparent,
                  ),
                  labelStyle: const TextStyle(color: Colors.transparent),
                  majorGridLines: const MajorGridLines(
                    width: 1.0,
                    color: ElevarmColors.grey100,
                  ),
                ),
                legend: Legend(
                  isVisible: true,
                  overflowMode: LegendItemOverflowMode.wrap,
                  position: LegendPosition.bottom,
                  legendItemBuilder: (legendText, series, point, index) {
                    return Padding(
                      padding: const EdgeInsets.only(
                        right: 6.0,
                        left: 6.0,
                        top: 16.0,
                      ),
                      child: FittedBox(
                        fit: BoxFit.scaleDown,
                        child: Row(
                          children: <Widget>[
                            Container(
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                color: (series as StackedColumnSeries).color,
                              ),
                              width: 8.0,
                              height: 8.0,
                            ),
                            const SizedBox(width: 8.0),
                            Text(
                              legendText,
                              style: ElevarmFontFamilies.inter(
                                color: ElevarmColors.grey600,
                                fontSize: ElevarmFontSizes.sm,
                                fontWeight: ElevarmFontWeights.regular,
                              ),
                            ),
                          ],
                        ),
                      ),
                    );
                  },
                ),
                tooltipBehavior: TooltipBehavior(
                  color:
                      const Color(0xFF2F2F2F), // FIXME: Not using ElevarmColors
                  enable: true,
                  builder: (data, point, series, pointIndex, seriesIndex) {
                    final chartData =
                        data as ElevarmStackedVerticalBarChartData;
                    final chartSeries = series as StackedColumnSeries<
                        ElevarmStackedVerticalBarChartData, String>;
                    return FittedBox(
                      fit: BoxFit.scaleDown,
                      child: Container(
                        decoration: BoxDecoration(
                          color: const Color(
                            0xFF2F2F2F,
                          ), // FIXME: Not using ElevarmColors
                          borderRadius: BorderRadius.circular(8.0),
                        ),
                        child: Padding(
                          padding: const EdgeInsets.symmetric(
                            vertical: 10.0,
                            horizontal: 12.0,
                          ),
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text(
                                tooltipTitle ?? title,
                                style: ElevarmFontFamilies.inter(
                                  color: const Color(
                                    0xFF9F9E9E,
                                  ), // FIXME: Not using ElevarmColors
                                  fontSize: ElevarmFontSizes.xs,
                                  fontWeight: ElevarmFontWeights.regular,
                                ),
                              ),
                              const SizedBox(height: 7.0),
                              Row(
                                children: [
                                  Container(
                                    decoration: BoxDecoration(
                                      shape: BoxShape.circle,
                                      color: chartSeries.color,
                                    ),
                                    width: 10.0,
                                    height: 10.0,
                                  ),
                                  const SizedBox(width: 7.0),
                                  Text(
                                    '${chartData.label}: ${chartData.value}',
                                    style: ElevarmFontFamilies.inter(
                                      color: ElevarmColors.white,
                                      fontSize: ElevarmFontSizes.xs,
                                      fontWeight: ElevarmFontWeights.regular,
                                    ),
                                  ),
                                ],
                              ),
                            ],
                          ),
                        ),
                      ),
                    );
                  },
                ),
                series: <
                    ChartSeries<ElevarmStackedVerticalBarChartData, String>>[
                  ...dataSource
                      .map(
                        (e) => StackedColumnSeries<
                            ElevarmStackedVerticalBarChartData, String>(
                          dataSource: e.dataPoints,
                          legendIconType: LegendIconType.circle,
                          name: e.label,
                          enableTooltip: true,
                          color: e.color,
                          xValueMapper:
                              (ElevarmStackedVerticalBarChartData data, _) =>
                                  data.label,
                          yValueMapper:
                              (ElevarmStackedVerticalBarChartData data, _) =>
                                  data.value,
                        ),
                      )
                      .toList(),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> elevarm_ui-0.4.0.tar.gz: lib/src/components/charts/bar_charts/elevarm_stacked_vertical_bar_chart_card.dart <==
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

/// [ElevarmStackedVerticalBarChartCard]'s data series class.
class ElevarmStackedVerticalBarChartDataSeries {
  /// The series' data points.
  final List<ElevarmStackedVerticalBarChartData> dataPoints;

  /// The series' color.
  final Color color;

  /// The series' label.
  final String label;

  ElevarmStackedVerticalBarChartDataSeries({
    required this.label,
    required this.dataPoints,
    required this.color,
  });
}

/// [ElevarmStackedVerticalBarChartCard]'s data point class.
class ElevarmStackedVerticalBarChartData {
  /// The data point's label.
  final String label;

  /// The data point's value.
  final int value;

  ElevarmStackedVerticalBarChartData({
    required this.label,
    required this.value,
  });
}

/// Elevarm UI's stacked vertical bar chart inside a card.
class ElevarmStackedVerticalBarChartCard extends StatelessWidget {
  /// Chart's title.
  final String title;

  /// Chart's subtitle if any.
  final String? subtitle;

  /// Chart's list of data.
  final List<ElevarmStackedVerticalBarChartDataSeries> dataSource;

  /// Chart's tooltip title. If null [title] will be used.
  final String? tooltipTitle;

  const ElevarmStackedVerticalBarChartCard({
    super.key,
    required this.title,
    this.subtitle,
    required this.dataSource,
    this.tooltipTitle,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.zero,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(12.0),
        boxShadow: ElevarmBoxShadow.sm,
        color: ElevarmColors.white,
      ),
      child: Padding(
        padding: const EdgeInsets.all(24.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text(
              title,
              style: ElevarmFontFamilies.inter(
                color: ElevarmColors.neutral,
                fontSize: ElevarmFontSizes.lg,
                fontWeight: ElevarmFontWeights.semibold,
              ),
            ),
            subtitle != null
                ? Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      const SizedBox(height: 2.0),
                      Text(
                        subtitle!,
                        style: ElevarmFontFamilies.inter(
                          color: const Color(
                            0xFF7A838F,
                          ), // FIXME: Not using ElevarmColors
                          fontSize: ElevarmFontSizes.sm,
                          fontWeight: ElevarmFontWeights.regular,
                        ),
                      ),
                    ],
                  )
                : Container(),
            const SizedBox(height: 8.0),
            SizedBox(
              height: 280,
              child: SfCartesianChart(
                margin: EdgeInsets.zero,
                primaryXAxis: CategoryAxis(
                  majorGridLines: const MajorGridLines(width: 0),
                  majorTickLines: const MajorTickLines(
                    color: Colors.transparent,
                  ),
                  axisLine: const AxisLine(
                    color: Colors.transparent,
                  ),
                  labelStyle: ElevarmFontFamilies.inter(
                    // ignore: deprecated_member_use_from_same_package
                    color: ElevarmColors.grey600, // FIXME
                    fontSize: ElevarmFontSizes.xs,
                    fontWeight: ElevarmFontWeights.regular,
                  ),
                ),
                plotAreaBorderColor: Colors.transparent,
                primaryYAxis: CategoryAxis(
                  maximumLabelWidth: 0.0,
                  axisLine: const AxisLine(
                    color: Colors.transparent,
                  ),
                  majorTickLines: const MajorTickLines(
                    color: Colors.transparent,
                  ),
                  labelStyle: const TextStyle(color: Colors.transparent),
                  majorGridLines: const MajorGridLines(
                    width: 1.0,
                    // ignore: deprecated_member_use_from_same_package
                    color: ElevarmColors.grey100, // FIXME
                  ),
                ),
                legend: Legend(
                  isVisible: true,
                  overflowMode: LegendItemOverflowMode.wrap,
                  position: LegendPosition.bottom,
                  legendItemBuilder: (legendText, series, point, index) {
                    return Padding(
                      padding: const EdgeInsets.only(
                        right: 6.0,
                        left: 6.0,
                        top: 16.0,
                      ),
                      child: FittedBox(
                        fit: BoxFit.scaleDown,
                        child: Row(
                          children: <Widget>[
                            Container(
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                color: (series as StackedColumnSeries).color,
                              ),
                              width: 8.0,
                              height: 8.0,
                            ),
                            const SizedBox(width: 8.0),
                            Text(
                              legendText,
                              style: ElevarmFontFamilies.inter(
                                // ignore: deprecated_member_use_from_same_package
                                color: ElevarmColors.grey600, // FIXME
                                fontSize: ElevarmFontSizes.sm,
                                fontWeight: ElevarmFontWeights.regular,
                              ),
                            ),
                          ],
                        ),
                      ),
                    );
                  },
                ),
                tooltipBehavior: TooltipBehavior(
                  color:
                      const Color(0xFF2F2F2F), // FIXME: Not using ElevarmColors
                  enable: true,
                  builder: (data, point, series, pointIndex, seriesIndex) {
                    final chartData =
                        data as ElevarmStackedVerticalBarChartData;
                    final chartSeries = series as StackedColumnSeries<
                        ElevarmStackedVerticalBarChartData, String>;
                    return FittedBox(
                      fit: BoxFit.scaleDown,
                      child: Container(
                        decoration: BoxDecoration(
                          color: const Color(
                            0xFF2F2F2F,
                          ), // FIXME: Not using ElevarmColors
                          borderRadius: BorderRadius.circular(8.0),
                        ),
                        child: Padding(
                          padding: const EdgeInsets.symmetric(
                            vertical: 10.0,
                            horizontal: 12.0,
                          ),
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text(
                                tooltipTitle ?? title,
                                style: ElevarmFontFamilies.inter(
                                  color: const Color(
                                    0xFF9F9E9E,
                                  ), // FIXME: Not using ElevarmColors
                                  fontSize: ElevarmFontSizes.xs,
                                  fontWeight: ElevarmFontWeights.regular,
                                ),
                              ),
                              const SizedBox(height: 7.0),
                              Row(
                                children: [
                                  Container(
                                    decoration: BoxDecoration(
                                      shape: BoxShape.circle,
                                      color: chartSeries.color,
                                    ),
                                    width: 10.0,
                                    height: 10.0,
                                  ),
                                  const SizedBox(width: 7.0),
                                  Text(
                                    '${chartData.label}: ${chartData.value}',
                                    style: ElevarmFontFamilies.inter(
                                      color: ElevarmColors.white,
                                      fontSize: ElevarmFontSizes.xs,
                                      fontWeight: ElevarmFontWeights.regular,
                                    ),
                                  ),
                                ],
                              ),
                            ],
                          ),
                        ),
                      ),
                    );
                  },
                ),
                series: <
                    ChartSeries<ElevarmStackedVerticalBarChartData, String>>[
                  ...dataSource
                      .map(
                        (e) => StackedColumnSeries<
                            ElevarmStackedVerticalBarChartData, String>(
                          dataSource: e.dataPoints,
                          legendIconType: LegendIconType.circle,
                          name: e.label,
                          enableTooltip: true,
                          color: e.color,
                          xValueMapper:
                              (ElevarmStackedVerticalBarChartData data, _) =>
                                  data.label,
                          yValueMapper:
                              (ElevarmStackedVerticalBarChartData data, _) =>
                                  data.value,
                        ),
                      )
                      .toList(),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
